pub struct SelectQuery<'a> {
pub table_name: &'a str,
pub distinct: bool,
pub columns: &'a [&'a str],
pub filters: Option<Vec<Box<dyn BooleanExpression>>>,
pub joins: Option<Vec<Join<'a>>>,
pub sorts: Option<Vec<Sort>>,
pub limit: Option<usize>,
}Fields
table_name: &'a strdistinct: boolcolumns: &'a [&'a str]filters: Option<Vec<Box<dyn BooleanExpression>>>joins: Option<Vec<Join<'a>>>sorts: Option<Vec<Sort>>limit: Option<usize>Implementations
Sourceimpl<'a> SelectQuery<'a>
impl<'a> SelectQuery<'a>
pub const fn distinct(self) -> Self
pub const fn columns(self, columns: &'a [&'a str]) -> Self
pub fn joins(self, joins: Vec<Join<'a>>) -> Self
pub fn join(self, table_name: &'a str, on: &'a str) -> Self
pub fn left_joins(self, left_joins: Vec<Join<'a>>) -> Self
pub fn left_join(self, table_name: &'a str, on: &'a str) -> Self
pub fn sorts(self, sorts: Vec<Sort>) -> Self
pub fn sort<T>(self, expression: T, direction: SortDirection) -> Selfwhere
T: Into<Identifier>,
pub const fn limit(self, limit: usize) -> Self
Sourcepub async fn execute(self, db: &dyn Database) -> Result<Vec<Row>, DatabaseError>
pub async fn execute(self, db: &dyn Database) -> Result<Vec<Row>, DatabaseError>
Errors
Will return Err if the select query execution failed.
Sourcepub async fn execute_first(
self,
db: &dyn Database,
) -> Result<Option<Row>, DatabaseError>
pub async fn execute_first( self, db: &dyn Database, ) -> Result<Option<Row>, DatabaseError>
Errors
Will return Err if the select query execution failed.